==> open-xchange-guard_2.10.1.orig.tar.bz2: open-xchange-guard-2.10.1/com.openexchange.guard.keymanagement.commons/src/com/openexchange/guard/keymanagement/commons/trust/GuardKeySources.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.keymanagement.commons.trust;

import com.openexchange.guard.configuration.GuardProperty;

/**
 * {@link GuardKeySources} defines a set of default Guard key sources ({@link KeySource}).
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.6.0
 */
public class GuardKeySources {

    /**
     * An Unknown source
     */
    public static KeySource UNKNOWN;

    /**
     * The {@link KeySource} for a regular user's key pair.
     */
    public static KeySource GUARD;

    /**
     * The {@link KeySource} for a public key uploaded by a user to {@link OGPGPKeysStorage}.
     */
    public static KeySource GUARD_USER_UPLOADED;

    /**
     * Key was uploaded by another user in the same context ID and shared
     */
    public static KeySource GUARD_USER_SHARED;

    /**
     * Initializes the key source values
     * @param keySourceFactory
     */
    public static void initialize(KeySourceFactory keySourceFactory) {
        UNKNOWN = keySourceFactory.create("UNKNOWN", 0);
        GUARD = keySourceFactory.create("GUARD_KEY_PAIR", GuardProperty.trustLevelGuard);
        GUARD_USER_UPLOADED = keySourceFactory.create("GUARD_USER_UPLOADED",GuardProperty.trustLevelGuardUserUploaded);
        GUARD_USER_SHARED = keySourceFactory.create("GUARD_USER_SHARED", GuardProperty.trustLevelGuardUserShared);
    }
}

==> open-xchange-guard_2.10.4.orig.tar.bz2: open-xchange-guard-2.10.4/com.openexchange.guard.keymanagement.commons/src/com/openexchange/guard/keymanagement/commons/trust/GuardKeySources.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.keymanagement.commons.trust;

import com.openexchange.guard.configuration.GuardProperty;

/**
 * {@link GuardKeySources} defines a set of default Guard key sources ({@link KeySource}).
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.6.0
 */
public class GuardKeySources {

    /**
     * An Unknown source
     */
    public static KeySource UNKNOWN;

    /**
     * The {@link KeySource} for a regular user's key pair.
     */
    public static KeySource GUARD;

    /**
     * The {@link KeySource} for a public key uploaded by a user to {@link OGPGPKeysStorage}.
     */
    public static KeySource GUARD_USER_UPLOADED;

    /**
     * Key was uploaded by another user in the same context ID and shared
     */
    public static KeySource GUARD_USER_SHARED;

    /**
     * Key created from incoming AutoCrypt Header
     */
    public static KeySource AUTOCRYPT_KEY;

    /**
     * Key created from incoming AutoCrypt Header AND manually verified by user
     */
    public static KeySource AUTOCRYPT_KEY_USER_VERIFIED;

    /**
     * Initializes the key source values
     * @param keySourceFactory
     */
    public static void initialize(KeySourceFactory keySourceFactory) {
        UNKNOWN = keySourceFactory.create("UNKNOWN", 0);
        GUARD = keySourceFactory.create("GUARD_KEY_PAIR", GuardProperty.trustLevelGuard);
        GUARD_USER_UPLOADED = keySourceFactory.create("GUARD_USER_UPLOADED",GuardProperty.trustLevelGuardUserUploaded);
        GUARD_USER_SHARED = keySourceFactory.create("GUARD_USER_SHARED", GuardProperty.trustLevelGuardUserShared);
        AUTOCRYPT_KEY = keySourceFactory.create("AUTOCRYPT_KEY", GuardProperty.trustLevelAutoCrypt);
        AUTOCRYPT_KEY_USER_VERIFIED = keySourceFactory.create("AUTOCRYPT_KEY_USER_VERIFIED", GuardProperty.trustLevelAutoCryptUserVerified);

    }
}
